@@ -5,8 +5,9 @@
 #' rates.
 #'
 #' @seealso [ts_c] to collect multiple time series
-#' @param ... ts-boxable time series, objects of class `ts`, `xts`, `data.frame`, `data.table`, or `tibble`. Or a numeric vector (see examples).
-#'
+#' @param ... ts-boxable time series, an object of class `ts`, `xts`, `zoo`,
+#'   `data.frame`, `data.table`, `tbl`, `tbl_ts`, `tbl_time`, `tis`, `irts` or
+#'   `timeSeries`.
 #' @return A ts-boxable object of the same class as the input.
 #' If series of different classes are combined, the class of the first series is
 #' used (if possible).
@@ -35,6 +36,8 @@ ts_bind <- function(...) {
 
 bind_numeric <- function(a, b, backwards = FALSE) {
 
+  .SD <- NULL
+
   if (!ts_boxable(a)) {stop("at least one object must be ts-boxable")}
 
   a <- ts_dts(copy(a))
@@ -51,10 +54,12 @@ bind_numeric <- function(a, b, backwards = FALSE) {
 
     if (!backwards){
       # having at least 5 obs allows time_shift to detect frequency
-      shft <- time_shift(x$time[(length(x$time) - per.to.add - 5):length(x$time)], per.to.add)
+      shft <- time_shift(
+        x$time[max(length(x$time) - per.to.add - 5, 1):length(x$time)], per.to.add
+      )
       new.time.stamps <- shft[(length(shft) - per.to.add + 1):length(shft)]
     } else {
-      shft <- time_shift(x$time[1:(per.to.add + 5)], -per.to.add)
+      shft <- time_shift(x$time[1:min(per.to.add + 5, length(x$time))], -per.to.add)
       new.time.stamps <- shft[1:per.to.add]
     }
 
