@@ -19,7 +19,9 @@ ts_default <- function(x) {
   if (inherits(x, "ts")) return(x)
   z <- ts_dts(x)
   cname <- dts_cname(z)
-  if (identical(cname$time, "time") && identical(cname$value, "value")) return(x)
+  if (identical(cname$time, "time") && identical(cname$value, "value")) {
+    return(x)
+  }
   setnames(z, cname$time, "time")
   setnames(z, cname$value, "value")
 
