@@ -1,13 +1,13 @@
 #' Plot Time Series, Using ggplot2
 #'
 #' `ts_ggplot()` has the same syntax and produces a similar plot as [ts_plot()],
-#' but uses the [ggplot2](https://ggplot2.tidyverse.org/) graphic system, and can be
-#' customized. With [theme_tsbox()] and [scale_color_tsbox()], the output of
-#' `ts_ggplot` has a similar look and feel.
+#' but uses the [ggplot2](https://ggplot2.tidyverse.org/) graphic system, and
+#' can be customized. With [theme_tsbox()] and [scale_color_tsbox()], the output
+#' of `ts_ggplot` has a similar look and feel.
 #'
-#' Both [ts_plot()] and `ts_ggplot()` combine multiple ID dimensions into a single
-#' dimension. To plot multiple dimensions in different shapes, facets, etc., use
-#' standard ggplot (see examples).
+#' Both [ts_plot()] and `ts_ggplot()` combine multiple ID dimensions into a
+#' single dimension. To plot multiple dimensions in different shapes, facets,
+#' etc., use standard ggplot (see examples).
 #'
 #' @param ... ts-boxable time series, objects of class `ts`, `xts`,
 #'   `data.frame`, `data.table`, or `tibble`. For `scale_` functions, arguments
@@ -48,7 +48,7 @@
 #'     ),
 #'     start = "1995-01-01"
 #'   ))) +
-#'   ggplot2::ggtitle("GDP and Consumer Sentiment", subtitle = "normalized values") +
+#'   ggplot2::ggtitle("GDP and Consumer Sentiment", subtitle = "normalized") +
 #'   theme_tsbox() +
 #'   scale_color_tsbox()
 #' }
@@ -68,7 +68,10 @@ ts_ggplot <- function(..., title, subtitle, ylab = "") {
   n <- NCOL(df)
   stopifnot(n > 1)
   if (n == 2) {
-    p <- ggplot2::ggplot(df, ggplot2::aes_string(x = cname$time, y = cname$value))
+    p <- ggplot2::ggplot(
+      df,
+      ggplot2::aes_string(x = cname$time, y = cname$value)
+    )
   } else if (n > 2) {
 
     # numeric variable 'levels'
@@ -77,9 +80,16 @@ ts_ggplot <- function(..., title, subtitle, ylab = "") {
     }
 
     if (length(unique(df[[cname$id]])) > 29) {
-      stop(length(unique(df[[cname$id]])), " time series supplied. Maximum is 29.", call. = FALSE)
+      stop(
+        length(unique(df[[cname$id]])),
+        " time series supplied. Maximum is 29.",
+        call. = FALSE
+      )
     }
-    p <- ggplot2::ggplot(df, ggplot2::aes_string(x = cname$time, y = cname$value, color = cname$id))
+    p <- ggplot2::ggplot(
+      df,
+      ggplot2::aes_string(x = cname$time, y = cname$value, color = cname$id)
+    )
   }
   p <- p + ggplot2::geom_line()
 
@@ -96,7 +106,8 @@ ts_ggplot <- function(..., title, subtitle, ylab = "") {
 
 #' @export
 #' @name ts_ggplot
-theme_tsbox <- function(base_family = getOption("ts_font", ""), base_size = 12) {
+theme_tsbox <- function(base_family = getOption("ts_font", ""),
+                        base_size = 12) {
 
   half_line <- base_size / 2
   ggplot2::theme_minimal(base_family = base_family, base_size = base_size) +
@@ -107,15 +118,35 @@ theme_tsbox <- function(base_family = getOption("ts_font", ""), base_size = 12)
         size = ggplot2::rel(0.9), color = "grey10",
         margin = ggplot2::margin(t = 0, r = 7, b = 0, l = 0)
       ),
-      plot.title = ggplot2::element_text(color = "grey10", face = "bold", margin = ggplot2::margin(t = half_line * 2, b = half_line * 0.7), hjust = 0, size = ggplot2::rel(1.2)),
-      plot.subtitle = ggplot2::element_text(color = "grey10", margin = ggplot2::margin(t = 0, b = half_line * 1.2), size = ggplot2::rel(0.9), hjust = 0),
-      plot.caption = ggplot2::element_text(color = "grey50", margin = ggplot2::margin(t = 0, b = half_line * 1.2), size = ggplot2::rel(0.8)),
+      plot.title = ggplot2::element_text(
+        color = "grey10",
+        face = "bold",
+        margin = ggplot2::margin(t = half_line * 2, b = half_line * 0.7),
+        hjust = 0, size = ggplot2::rel(1.2)
+      ),
+      plot.subtitle = ggplot2::element_text(
+        color = "grey10",
+        margin = ggplot2::margin(t = 0, b = half_line * 1.2),
+        size = ggplot2::rel(0.9),
+        hjust = 0
+      ),
+      plot.caption = ggplot2::element_text(
+        color = "grey50",
+        margin = ggplot2::margin(t = 0, b = half_line * 1.2),
+        size = ggplot2::rel(0.8)
+      ),
 
       panel.grid = ggplot2::element_line(size = 0.2),
 
-      axis.text = ggplot2::element_text(color = "grey10", size = ggplot2::rel(0.7)),
+      axis.text = ggplot2::element_text(
+        color = "grey10",
+        size = ggplot2::rel(0.7)
+      ),
       legend.title = ggplot2::element_blank(),
-      legend.text = ggplot2::element_text(color = "grey10", size = ggplot2::rel(0.9)),
+      legend.text = ggplot2::element_text(
+        color = "grey10",
+        size = ggplot2::rel(0.9)
+      ),
       legend.position = "bottom",
       legend.direction = "horizontal"
     )
@@ -130,7 +161,8 @@ colors_tsbox <- function() {
     "#4D4D4D",
     # Okabe and Ito, colorblindr, https://jfly.uni-koeln.de/color/,
     # with orange moved to position 2
-    "#56B4E9", "#E69F00", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7", "#999999",
+    "#56B4E9", "#E69F00", "#009E73", "#F0E442", "#0072B2", "#D55E00",
+    "#CC79A7", "#999999",
     # Additional Colors
     "#4AFFF0", "#34BDCC", "#4F61A1", "#461E78", "#440A4F", "#C3FBC4",
     "#85F9D6", "#79C7AD", "#A6CC7A", "#DFFF7B",
@@ -143,14 +175,24 @@ colors_tsbox <- function() {
 #' @name ts_ggplot
 scale_color_tsbox <- function(...) {
   stopifnot(requireNamespace("ggplot2"))
-  ggplot2::discrete_scale("colour", "ds", scales::manual_pal(colors_tsbox()), ...)
+  ggplot2::discrete_scale(
+    "colour",
+    "ds",
+    scales::manual_pal(colors_tsbox()),
+    ...
+  )
 }
 
 #' @export
 #' @name ts_ggplot
 scale_fill_tsbox <- function(...) {
   stopifnot(requireNamespace("ggplot2"))
-  ggplot2::discrete_scale("fill", "ds", scales::manual_pal(colors_tsbox()), ...)
+  ggplot2::discrete_scale(
+    "fill",
+    "ds",
+    scales::manual_pal(colors_tsbox()),
+    ...
+  )
 }
 
 
